@@ -14,18 +14,22 @@
  *  See the License for the specific language governing permissions and
  *  limitations under the License.
  */
-
 package org.apache.tomcat.jni;
 
 /* Import needed classes */
 import java.nio.ByteBuffer;
 
-/** Socket
+/**
+ * Socket
  *
  * @author Mladen Turk
- * @version $Revision: 467222 $, $Date: 2006-10-24 05:17:11 +0200 (Tue, 24 Oct 2006) $
+ *
+ * @deprecated  The scope of the APR/Native Library will be reduced in Tomcat
+ *              10.1.x / Tomcat Native 2.x onwards to only include those
+ *              components required to provide OpenSSL integration with the NIO
+ *              and NIO2 connectors.
  */
-
+@Deprecated
 public class Socket {
 
     /* Standard socket defines */
@@ -34,23 +38,34 @@ public class Socket {
     /*
      * apr_sockopt Socket option definitions
      */
-    public static final int APR_SO_LINGER       = 1;    /** Linger */
-    public static final int APR_SO_KEEPALIVE    = 2;    /** Keepalive */
-    public static final int APR_SO_DEBUG        = 4;    /** Debug */
-    public static final int APR_SO_NONBLOCK     = 8;    /** Non-blocking IO */
-    public static final int APR_SO_REUSEADDR    = 16;   /** Reuse addresses */
-    public static final int APR_SO_SNDBUF       = 64;   /** Send buffer */
-    public static final int APR_SO_RCVBUF       = 128;  /** Receive buffer */
-    public static final int APR_SO_DISCONNECTED = 256;  /** Disconnected */
+    /** Linger */
+    public static final int APR_SO_LINGER       = 1;
+    /** Keepalive */
+    public static final int APR_SO_KEEPALIVE    = 2;
+    /** Debug */
+    public static final int APR_SO_DEBUG        = 4;
+    /** Non-blocking IO */
+    public static final int APR_SO_NONBLOCK     = 8;
+    /** Reuse addresses */
+    public static final int APR_SO_REUSEADDR    = 16;
+    /** Send buffer */
+    public static final int APR_SO_SNDBUF       = 64;
+    /** Receive buffer */
+    public static final int APR_SO_RCVBUF       = 128;
+    /** Disconnected */
+    public static final int APR_SO_DISCONNECTED = 256;
     /** For SCTP sockets, this is mapped to STCP_NODELAY internally. */
     public static final int APR_TCP_NODELAY     = 512;
-    public static final int APR_TCP_NOPUSH      = 1024; /** No push */
-    /** This flag is ONLY set internally when we set APR_TCP_NOPUSH with
+    /** No push */
+    public static final int APR_TCP_NOPUSH      = 1024;
+    /**
+     * This flag is ONLY set internally when we set APR_TCP_NOPUSH with
      * APR_TCP_NODELAY set to tell us that APR_TCP_NODELAY should be turned on
      * again when NOPUSH is turned off
      */
     public static final int APR_RESET_NODELAY   = 2048;
-    /** Set on non-blocking sockets (timeout != 0) on which the
+    /**
+     * Set on non-blocking sockets (timeout != 0) on which the
      * previous read() did not fill a buffer completely.  the next
      * apr_socket_recv()  will first call select()/poll() rather than
      * going straight into read().  (Can also be set by an application to
@@ -58,38 +73,36 @@ public class Socket {
      * the app expects that an immediate read would fail.)
      */
     public static final int APR_INCOMPLETE_READ = 4096;
-    /** like APR_INCOMPLETE_READ, but for write
-     */
+    /** like APR_INCOMPLETE_READ, but for write */
     public static final int APR_INCOMPLETE_WRITE = 8192;
-    /** Don't accept IPv4 connections on an IPv6 listening socket.
-     */
+    /** Don't accept IPv4 connections on an IPv6 listening socket. */
     public static final int APR_IPV6_V6ONLY      = 16384;
-    /** Delay accepting of new connections until data is available.
-     */
+    /** Delay accepting of new connections until data is available. */
     public static final int APR_TCP_DEFER_ACCEPT = 32768;
 
-    /** Define what type of socket shutdown should occur.
+    /* Define what type of socket shutdown should occur.
      * apr_shutdown_how_e enum
      */
-    public static final int APR_SHUTDOWN_READ      = 0; /** no longer allow read request */
-    public static final int APR_SHUTDOWN_WRITE     = 1; /** no longer allow write requests */
-    public static final int APR_SHUTDOWN_READWRITE = 2; /** no longer allow read or write requests */
+    /** no longer allow read request */
+    public static final int APR_SHUTDOWN_READ      = 0;
+    /** no longer allow write requests */
+    public static final int APR_SHUTDOWN_WRITE     = 1;
+    /** no longer allow read or write requests */
+    public static final int APR_SHUTDOWN_READWRITE = 2;
 
     public static final int APR_IPV4_ADDR_OK = 0x01;
     public static final int APR_IPV6_ADDR_OK = 0x02;
 
-    /* TODO: Missing:
-     * APR_INET
-     * APR_UNSPEC
-     * APR_INET6
-     */
     public static final int APR_UNSPEC = 0;
     public static final int APR_INET   = 1;
     public static final int APR_INET6  = 2;
 
-    public static final int APR_PROTO_TCP  =   6; /** TCP  */
-    public static final int APR_PROTO_UDP  =  17; /** UDP  */
-    public static final int APR_PROTO_SCTP = 132; /** SCTP */
+    /** TCP  */
+    public static final int APR_PROTO_TCP  =   6;
+    /** UDP  */
+    public static final int APR_PROTO_UDP  =  17;
+    /** SCTP */
+    public static final int APR_PROTO_SCTP = 132;
 
     /**
      * Enum to tell us if we're interested in remote or local socket
@@ -111,6 +124,7 @@ public class Socket {
      * @param protocol The protocol of the socket (e.g., APR_PROTO_TCP).
      * @param cont The parent pool to use
      * @return The new socket that has been set up.
+     * @throws Exception Error creating socket
      */
     public static native long create(int family, int type,
                                      int protocol, long cont)
@@ -119,7 +133,7 @@ public class Socket {
 
     /**
      * Shutdown either reading, writing, or both sides of a socket.
-     * <br />
+     * <br>
      * This does not actually close the socket descriptor, it just
      *      controls which calls are still valid on the socket.
      * @param thesocket The socket to close
@@ -129,12 +143,14 @@ public class Socket {
      * APR_SHUTDOWN_WRITE        no longer allow write requests
      * APR_SHUTDOWN_READWRITE    no longer allow read or write requests
      * </PRE>
+     * @return the operation status
      */
     public static native int shutdown(long thesocket, int how);
 
     /**
      * Close a socket.
      * @param thesocket The socket to close
+     * @return the operation status
      */
     public static native int close(long thesocket);
 
@@ -150,6 +166,7 @@ public class Socket {
      * @param sa The socket address to bind to
      * This may be where we will find out if there is any other process
      *      using the selected port.
+     * @return the operation status
      */
     public static native int bind(long sock, long sa);
 
@@ -159,6 +176,7 @@ public class Socket {
      * @param backlog The number of outstanding connections allowed in the sockets
      *                listen queue.  If this value is less than zero, the listen
      *                queue size is set to zero.
+     * @return the operation status
      */
     public static native int listen(long sock, int backlog);
 
@@ -169,6 +187,18 @@ public class Socket {
      * @return  A copy of the socket that is connected to the socket that
      *          made the connection request.  This is the socket which should
      *          be used for all future communication.
+     * @throws Exception Socket accept error
+     */
+    public static native long acceptx(long sock, long pool)
+        throws Exception;
+
+    /**
+     * Accept a new connection request
+     * @param sock The socket we are listening on.
+     * @return  A copy of the socket that is connected to the socket that
+     *          made the connection request.  This is the socket which should
+     *          be used for all future communication.
+     * @throws Exception Socket accept error
      */
     public static native long accept(long sock)
         throws Exception;
@@ -179,14 +209,15 @@ public class Socket {
      * @param name The accept filter
      * @param args Any extra args to the accept filter.  Passing NULL here removes
      *             the accept filter.
+     * @return the operation status
      */
     public static native int acceptfilter(long sock, String name, String args);
 
     /**
      * Query the specified socket if at the OOB/Urgent data mark
      * @param sock The socket to query
-     * @return True if socket is at the OOB/urgent mark,
-     *         otherwise return false.
+     * @return <code>true</code> if socket is at the OOB/urgent mark,
+     *         otherwise <code>false</code>.
      */
     public static native boolean atmark(long sock);
 
@@ -195,6 +226,7 @@ public class Socket {
      * or a different one.
      * @param sock The socket we wish to use for our side of the connection
      * @param sa The address of the machine we wish to connect to.
+     * @return the operation status
      */
     public static native int connect(long sock, long sa);
 
@@ -213,8 +245,7 @@ public class Socket {
      * @param buf The buffer which contains the data to be sent.
      * @param offset Offset in the byte buffer.
      * @param len The number of bytes to write; (-1) for full array.
-     * @return The number of bytes send.
-     *
+     * @return The number of bytes sent
      */
     public static native int send(long sock, byte[] buf, int offset, int len);
 
@@ -236,17 +267,60 @@ public class Socket {
      *               and no larger than buf.length
      * @param len The maximum number of buffers to be accessed; must be non-negative
      *            and no larger than buf.length - offset
-     * @return The number of bytes send.
-     *
+     * @return The number of bytes sent
      */
     public static native int sendb(long sock, ByteBuffer buf,
                                    int offset, int len);
+
+    /**
+     * Send data over a network without retry
+     * <PRE>
+     * This functions acts like a blocking write by default.  To change
+     * this behavior, use apr_socket_timeout_set() or the APR_SO_NONBLOCK
+     * socket option.
+     *
+     * It is possible for both bytes to be sent and an error to be returned.
+     *
+     * </PRE>
+     * @param sock The socket to send the data over.
+     * @param buf The Byte buffer which contains the data to be sent.
+     * @param offset The offset within the buffer array of the first buffer from
+     *               which bytes are to be retrieved; must be non-negative
+     *               and no larger than buf.length
+     * @param len The maximum number of buffers to be accessed; must be non-negative
+     *            and no larger than buf.length - offset
+     * @return The number of bytes sent
+     */
+    public static native int sendib(long sock, ByteBuffer buf,
+                                    int offset, int len);
+
     /**
      * Send data over a network using internally set ByteBuffer
+     * @param sock The socket to send the data over.
+     * @param offset The offset within the buffer array of the first buffer from
+     *               which bytes are to be retrieved; must be non-negative
+     *               and no larger than buf.length
+     * @param len The maximum number of buffers to be accessed; must be non-negative
+     *            and no larger than buf.length - offset
+     * @return The number of bytes sent
      */
     public static native int sendbb(long sock,
                                    int offset, int len);
 
+    /**
+     * Send data over a network using internally set ByteBuffer
+     * without internal retry.
+     * @param sock The socket to send the data over.
+     * @param offset The offset within the buffer array of the first buffer from
+     *               which bytes are to be retrieved; must be non-negative
+     *               and no larger than buf.length
+     * @param len The maximum number of buffers to be accessed; must be non-negative
+     *            and no larger than buf.length - offset
+     * @return The number of bytes sent
+     */
+    public static native int sendibb(long sock,
+                                     int offset, int len);
+
     /**
      * Send multiple packets of data over a network.
      * <PRE>
@@ -261,7 +335,7 @@ public class Socket {
      * </PRE>
      * @param sock The socket to send the data over.
      * @param vec The array from which to get the data to send.
-     *
+     * @return The number of bytes sent
      */
     public static native int sendv(long sock, byte[][] vec);
 
@@ -272,6 +346,7 @@ public class Socket {
      * @param buf  The data to send
      * @param offset Offset in the byte buffer.
      * @param len  The length of the data to send
+     * @return The number of bytes sent
      */
     public static native int sendto(long sock, long where, int flags,
                                     byte[] buf, int offset, int len);
@@ -340,12 +415,23 @@ public class Socket {
      * @param buf The buffer to store the data in.
      * @param offset Offset in the byte buffer.
      * @param nbytes The number of bytes to read (-1) for full array.
-     * @return the number of bytes received.
+     * @return If &ge; 0, the return value is the number of bytes read. Note a
+     *         non-blocking read with no data current available will return
+     *         {@link Status#EAGAIN} and EOF will return {@link Status#APR_EOF}.
      */
     public static native int recvb(long sock, ByteBuffer buf,
                                    int offset, int nbytes);
+
     /**
-     * Read data from a network using internally set ByteBuffer
+     * Read data from a network using internally set ByteBuffer.
+     *
+     * @param sock The socket to read the data from.
+     * @param offset Offset in the byte buffer.
+     * @param nbytes The number of bytes to read (-1) for full array.
+     * @return If &gt; 0, the return value is the number of bytes read. If == 0,
+     *         the return value indicates EOF and if &lt; 0 the return value is the
+     *         error code. Note a non-blocking read with no data current
+     *         available will return {@link Status#EAGAIN} not zero.
      */
     public static native int recvbb(long sock,
                                     int offset, int nbytes);
@@ -374,6 +460,11 @@ public class Socket {
                                     int offset, int nbytes, long timeout);
     /**
      * Read data from a network with timeout using internally set ByteBuffer
+     * @param sock The socket to read the data from.
+     * @param offset Offset in the byte buffer.
+     * @param nbytes The number of bytes to read (-1) for full array.
+     * @param timeout The socket timeout in microseconds.
+     * @return the number of bytes received.
      */
     public static native int recvbbt(long sock,
                                      int offset, int nbytes, long timeout);
@@ -387,7 +478,7 @@ public class Socket {
      * @param nbytes The number of bytes to read (-1) for full array.
      * @return the number of bytes received.
      */
-    public static native int recvFrom(long from, long sock, int flags,
+    public static native int recvfrom(long from, long sock, int flags,
                                       byte[] buf, int offset, int nbytes);
 
     /**
@@ -411,6 +502,7 @@ public class Socket {
      * APR_SO_RCVBUF     --  Set the ReceiveBufferSize
      * </PRE>
      * @param on Value for the option.
+     * @return the operation status
      */
     public static native int optSet(long sock, int opt, int on);
 
@@ -432,6 +524,7 @@ public class Socket {
      *                       (Currently only used on Windows)
      * </PRE>
      * @return Socket option returned on the call.
+     * @throws Exception An error occurred
      */
     public static native int optGet(long sock, int opt)
         throws Exception;
@@ -441,11 +534,12 @@ public class Socket {
      * @param sock The socket to set up.
      * @param t Value for the timeout in microseconds.
      * <PRE>
-     * t > 0  -- read and write calls return APR_TIMEUP if specified time
-     *           elapsess with no data read or written
+     * t &gt; 0  -- read and write calls return APR_TIMEUP if specified time
+     *           elapses with no data read or written
      * t == 0 -- read and write calls never block
-     * t < 0  -- read and write calls block
+     * t &lt; 0  -- read and write calls block
      * </PRE>
+     * @return the operation status
      */
     public static native int timeoutSet(long sock, long t);
 
@@ -453,6 +547,7 @@ public class Socket {
      * Query socket timeout for the specified socket
      * @param sock The socket to query
      * @return Socket timeout returned from the query.
+     * @throws Exception An error occurred
      */
     public static native long timeoutGet(long sock)
         throws Exception;
@@ -460,7 +555,7 @@ public class Socket {
     /**
      * Send a file from an open file descriptor to a socket, along with
      * optional headers and trailers.
-     * <br />
+     * <br>
      * This functions acts like a blocking write by default.  To change
      *         this behavior, use apr_socket_timeout_set() or the
      *         APR_SO_NONBLOCK socket option.
@@ -476,7 +571,6 @@ public class Socket {
      * @param flags APR flags that are mapped to OS specific flags
      * @return Number of bytes actually sent, including headers,
      *         file, and trailers
-     *
      */
     public static native long sendfile(long sock, long file, byte [][] headers,
                                        byte[][] trailers, long offset,
@@ -484,6 +578,12 @@ public class Socket {
 
     /**
      * Send a file without header and trailer arrays.
+     * @param sock The socket to which we're writing
+     * @param file The open file from which to read
+     * @param offset Offset into the file where we should begin writing
+     * @param len Number of bytes to send from the file
+     * @param flags APR flags that are mapped to OS specific flags
+     * @return Number of bytes actually sent
      */
     public static native long sendfilen(long sock, long file, long offset,
                                         long len, int flags);
@@ -491,13 +591,15 @@ public class Socket {
     /**
      * Create a child pool from associated socket pool.
      * @param thesocket The socket to use
+     * @return a pointer to the pool
+     * @throws Exception An error occurred
      */
     public static native long pool(long thesocket)
         throws Exception;
 
     /**
-     * Private method for geting the socket struct members
-     * @param socket The soocket to use
+     * Private method for getting the socket struct members
+     * @param socket The socket to use
      * @param what Struct member to obtain
      * <PRE>
      * SOCKET_GET_POOL  - The socket pool
@@ -505,7 +607,7 @@ public class Socket {
      * SOCKET_GET_APRS  - APR socket
      * SOCKET_GET_TYPE  - Socket type
      * </PRE>
-     * @return The stucture member address
+     * @return The structure member address
      */
     private static native long get(long socket, int what);
 
@@ -513,7 +615,7 @@ public class Socket {
      * Set internal send ByteBuffer.
      * This function will preset internal Java ByteBuffer for
      * consecutive sendbb calls.
-     * @param thesocket The socket to use
+     * @param sock The socket to use
      * @param buf The ByteBuffer
      */
     public static native void setsbb(long sock, ByteBuffer buf);
@@ -522,8 +624,26 @@ public class Socket {
      * Set internal receive ByteBuffer.
      * This function will preset internal Java ByteBuffer for
      * consecutive revcvbb/recvbbt calls.
-     * @param thesocket The socket to use
+     * @param sock The socket to use
      * @param buf The ByteBuffer
      */
     public static native void setrbb(long sock, ByteBuffer buf);
+
+    /**
+     * Set the data associated with the current socket.
+     * @param sock The currently open socket.
+     * @param data The user data to associate with the socket.
+     * @param key The key to associate with the data.
+     * @return the operation status
+     */
+      public static native int dataSet(long sock, String key, Object data);
+
+    /**
+     * Return the data associated with the current socket
+     * @param sock The currently open socket.
+     * @param key The key to associate with the user data.
+     * @return Data or null in case of error.
+     */
+     public static native Object dataGet(long sock, String key);
+
 }
